===================
SQLAlchemy 2 Stubs
===================

These are PEP-484 typing stubs for `SQLAlchemy <https://www.sqlalchemy.org>`_
1.4 and 2.0.  They are released concurrently along with
a `Mypy extension <https://docs.sqlalchemy.org/en/14/orm/extensions/mypy.html>`_
which is designed to work with these stubs, which assists primarily in the
area of ORM mappings.

The stubs replace the use of the "sqlalchemy-stubs" package published by
Dropbox.  Differences include that these stubs are generated against
1.4's API as well as some adjustments to the use of generics.

This project should be considered **alpha level** and is not as mature
as the Dropbox stubs for the initial release.

See the Mypy plugin documentation at https://docs.sqlalchemy.org/en/14/orm/extensions/mypy.html
for an overview of how to use PEP-484 annotations with ORM mapped classes.

Code of Conduct
---------------

Above all, SQLAlchemy places great emphasis on polite, thoughtful, and
constructive communication between users and developers.
Please see our current Code of Conduct at
`Code of Conduct <http://www.sqlalchemy.org/codeofconduct.html>`_.

License
-------

SQLAlchemy is distributed under the `MIT license
<http://www.opensource.org/licenses/mit-license.php>`_.

